==> jc-1.4.0.tar.gz: soot/jimple/parser/node/TChar.h <==
// public final class soot.jimple.parser.node.TChar

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 49130f858f07806e soot_jimple_parser_node_TChar
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TChar_H_
#define _JC_soot_jimple_parser_node_TChar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TChar$sub_refs	_jc_soot_jimple_parser_node_TChar$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TChar$sub_nonrefs	_jc_soot_jimple_parser_node_TChar$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TChar$refs	_jc_soot_jimple_parser_node_TChar$refs;
typedef struct _jc_soot_jimple_parser_node_TChar$nonrefs	_jc_soot_jimple_parser_node_TChar$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TChar$object	_jc_soot_jimple_parser_node_TChar$object;

typedef const struct _jc_soot_jimple_parser_node_TChar$vmethods	_jc_soot_jimple_parser_node_TChar$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TChar$vtable	_jc_soot_jimple_parser_node_TChar$vtable;
typedef const struct _jc_soot_jimple_parser_node_TChar$vtype	_jc_soot_jimple_parser_node_TChar$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TChar$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *);
extern void _jc_soot_jimple_parser_node_TChar$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, jint, jint);

// Virtual methods
extern void _jc_soot_jimple_parser_node_TChar$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TChar$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *);
extern void _jc_soot_jimple_parser_node_TChar$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TChar$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *);
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_TChar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TChar$vmethods	soot_jimple_parser_node_TChar;
};

// Vtype
struct _jc_soot_jimple_parser_node_TChar$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TChar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TChar$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TChar$refs {
    _jc_soot_jimple_parser_node_TChar$sub_refs	soot_jimple_parser_node_TChar;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TChar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TChar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TChar$sub_nonrefs	soot_jimple_parser_node_TChar;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TChar$object {
	_jc_soot_jimple_parser_node_TChar$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TChar$vtype	*vtype;
	_jc_soot_jimple_parser_node_TChar$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TChar$vtype _jc_soot_jimple_parser_node_TChar$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TChar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TChar$class_object;

#endif	/* _JC_soot_jimple_parser_node_TChar_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/TChar.h <==
// public final class soot.jimple.parser.node.TChar

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 49130f858f07806e soot_jimple_parser_node_TChar
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TChar_H_
#define _JC_soot_jimple_parser_node_TChar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TChar$sub_refs	_jc_soot_jimple_parser_node_TChar$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TChar$sub_nonrefs	_jc_soot_jimple_parser_node_TChar$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TChar$refs	_jc_soot_jimple_parser_node_TChar$refs;
typedef struct _jc_soot_jimple_parser_node_TChar$nonrefs	_jc_soot_jimple_parser_node_TChar$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TChar$object	_jc_soot_jimple_parser_node_TChar$object;

typedef const struct _jc_soot_jimple_parser_node_TChar$vmethods	_jc_soot_jimple_parser_node_TChar$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TChar$vtable	_jc_soot_jimple_parser_node_TChar$vtable;
typedef const struct _jc_soot_jimple_parser_node_TChar$vtype	_jc_soot_jimple_parser_node_TChar$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TChar$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TChar$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_TChar$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TChar$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TChar$method$setText$2774cf9ec78ebefc(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_TChar$method_info$setText$2774cf9ec78ebefc;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TChar$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *) _JC_JCNI_ATTR;
	void	(*setText$2774cf9ec78ebefc)(_jc_env *, struct _jc_soot_jimple_parser_node_TChar$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_TChar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TChar$vmethods	soot_jimple_parser_node_TChar;
};

// Vtype
struct _jc_soot_jimple_parser_node_TChar$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TChar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TChar$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TChar$refs {
    _jc_soot_jimple_parser_node_TChar$sub_refs	soot_jimple_parser_node_TChar;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TChar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TChar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TChar$sub_nonrefs	soot_jimple_parser_node_TChar;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TChar$object {
	_jc_soot_jimple_parser_node_TChar$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TChar$vtype	*vtype;
	_jc_soot_jimple_parser_node_TChar$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TChar$vtype _jc_soot_jimple_parser_node_TChar$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TChar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TChar$class_object;

#endif	/* _JC_soot_jimple_parser_node_TChar_H_ */
